@@ -1,21 +1,21 @@
 #
 # Copyright 2008-2014 Universidad Complutense de Madrid
-# 
+#
 # This file is part of Numina
-# 
+#
 # Numina is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # Numina is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with Numina.  If not, see <http://www.gnu.org/licenses/>.
-# 
+#
 
 from .recipes import BaseRecipe
 from .recipes import list_recipes
@@ -27,10 +27,16 @@ from .pipeline import drp_load, init_drp_system
 from .requirements import DataProductRequirement
 from .load import RequirementParser
 from .requirements import Parameter, Requirement
-from .products import DataProduct, FrameDataProduct
+from .products import DataProductType, DataFrameType
+from .oresult import ObservationResult
 from numina.exceptions import RecipeError
-from .recipereqs import RecipeRequirements, define_requirements
-from .reciperesult import RecipeResult, Product, Optional
-from .reciperesult import define_result
+from numina.exceptions import ValidationError
+from .recipeinout import RecipeRequirements, define_requirements
+from .recipeinout import RecipeResult, define_result
+from .recipeinout import ErrorRecipeResult, BaseRecipeResult
+from .dataholders import Product
 from .oresult import obsres_from_dict
 from .qc import QC
+
+FrameDataProduct = DataFrameType
+DataProduct = DataProductType
