@@ -1,34 +1,34 @@
 #
 # Copyright 2008-2014 Universidad Complutense de Madrid
-# 
+#
 # This file is part of Numina
-# 
+#
 # Numina is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # Numina is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with Numina.  If not, see <http://www.gnu.org/licenses/>.
-# 
+#
 
 '''
 Basic Data Products
 '''
 
-
 from astropy.io import fits
 
+
 class DataFrame(object):
     '''A handle to a image in disk or in memory.'''
     def __init__(self, frame=None, filename=None):
         if frame is None and filename is None:
-            raise ValueError('only one in frame and filename can be None') 
+            raise ValueError('only one in frame and filename can be None')
         self.frame = frame
         self.filename = filename
 
@@ -48,5 +48,5 @@ class DataFrame(object):
         elif self.filename is None:
             return "DataFrame(frame=%r)" % self.frame
         else:
-            return "DataFrame(filename=%r, frame=%r)" % (self.filename, self.frame)
-
+            fmt = "DataFrame(filename=%r, frame=%r)"
+            return fmt % (self.filename, self.frame)
