@@ -1,26 +1,29 @@
 #
 # Copyright 2008-2014 Universidad Complutense de Madrid
-# 
+#
 # This file is part of Numina
-# 
+#
 # Numina is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # Numina is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with Numina.  If not, see <http://www.gnu.org/licenses/>.
-# 
+#
 
 import inspect
 
+from numina.exceptions import ValidationError
+
+
 class DataType(object):
-    
+
     def __init__(self, ptype, default=None):
         self.python_type = ptype
         self.default = default
@@ -28,9 +31,12 @@ class DataType(object):
 
     def store(self, obj):
         return obj
-    
+
     def validate(self, obj):
-        return isinstance(obj, self.python_type)
+        if not isinstance(obj, self.python_type):
+            raise ValidationError(obj, self.python_type)
+        return True
+
 
 class NullType(DataType):
 
@@ -42,7 +48,10 @@ class NullType(DataType):
         return None
 
     def validate(self, obj):
-        return obj is None
+        if obj is not None:
+            raise ValidationError
+        return True
+
 
 class PlainPythonType(DataType):
     def __init__(self, ref=None):
@@ -51,14 +60,15 @@ class PlainPythonType(DataType):
         super(PlainPythonType, self).__init__(stype, default=default)
         self.dialect = stype
 
-class ListOf(DataType):
+
+class ListOfType(DataType):
     def __init__(self, ref):
         stype = list
         if inspect.isclass(ref):
             self.internal = ref()
         else:
             self.internal = ref
-        super(ListOf, self).__init__(stype)
+        super(ListOfType, self).__init__(stype)
         self.dialect = {}
 
     def store(self, obj):
@@ -67,28 +77,5 @@ class ListOf(DataType):
 
     def validate(self, obj):
         for o in obj:
-            if not self.internal.validate(o):
-                return False
-
-
-import pkgutil
-import numina.ext as namespace
-
-def default_dialect_info(obj):
-    key = obj.__module__ + '.' + obj.__class__.__name__
-    result = {'base': {'fqn': key, 'python': obj.python_type}}
-    return result
-
-for imp, name, _is_pkg in pkgutil.walk_packages(namespace.__path__, namespace.__name__ + '.'):
-    try:
-        loader = imp.find_module(name)
-        mod = loader.load_module(name)
-        dialect_info = getattr(mod, 'dialect_info')
-        if dialect_info:
-            break
-    except StandardError as error:
-        #print name, type(error), error
-        pass
-else:
-    dialect_info = default_dialect_info
-
+            self.internal.validate(o)
+        return True
