@@ -17,14 +17,17 @@
 # $Log: sextractor.py,v $
 # Revision 1.2  2005/07/06 21:40:43  hack
 # Tweakshifts version 0.5.0 (WJH):
-#   - added support for SExtractor PSET and user-supplied SExtractor config file
-#   - added 'nbright' parameter for selecting only 'nbright' objects for matching
+#   - added support for SExtractor PSET and
+#     user-supplied SExtractor config file
+#   - added 'nbright' parameter for selecting
+#     only 'nbright' objects for matching
 #   - redefined 'ascend' to 'fluxunits' of 'counts/cps/mag'
 #   - fixed bug in countSExtractorObjects()reported by Andy
 #   - turned off overwriting of output WCS file
 #
 # Revision 1.15  2005/06/29 13:07:41  hack
-# Added Python interface to SExtractor to STSDAS$Python for use with 'tweakshifts'. WJH
+# Added Python interface to SExtractor to
+# STSDAS$Python for use with 'tweakshifts'. WJH
 # Added 3 more parameters to config
 #
 # Revision 1.14  2005/02/14 19:27:31  laurentl
@@ -65,7 +68,7 @@
 #
 # Revision 1.3  2005/01/06 13:37:11  laurentl
 # *** empty log message ***
-# 
+#
 #
 # ======================================================================
 
@@ -161,17 +164,19 @@ __version__ = "1.15.0 (2005-07-06)"
 
 # ======================================================================
 
+
 class SExtractorException(Exception):
     pass
 
 # ======================================================================
 
 nnw_config = \
-"""NNW
+    """NNW
 # Neural Network Weights for the SExtractor star/galaxy classifier (V1.3)
 # inputs:    9 for profile parameters + 1 for seeing.
 # outputs:    ``Stellarity index'' (0.0 to 1.0)
-# Seeing FWHM range: from 0.025 to 5.5'' (images must have 1.5 < FWHM < 5 pixels)
+# Seeing FWHM range: from 0.025 to 5.5''
+# (images must have 1.5 < FWHM < 5 pixels)
 # Optimized for Moffat profiles with 2<= beta <= 4.
 
  3 10 10  1
@@ -193,116 +198,119 @@ nnw_config = \
 -1.70059e+00 -3.65695e+00  1.22367e+00 -5.74367e-01 -3.29571e+00  2.46316e+00  5.22353e+00  2.42038e+00  1.22919e+00 -9.22250e-01 -2.32028e+00
 
 
- 0.00000e+00 
- 1.00000e+00 
+ 0.00000e+00
+ 1.00000e+00
 """
 
 # ======================================================================
 
+
 class SExtractor:
+
     """
     A wrapper class to transparently use SExtractor.
 
     """
 
-    _SE_config = { 
+    _SE_config = {
         "CATALOG_NAME":
         {"comment": "name of the output catalog",
          "value": "py-sextractor.cat"},
-        
+
         "CATALOG_TYPE":
         {"comment":
          '"NONE","ASCII_HEAD","ASCII","FITS_1.0" or "FITS_LDAC"',
          "value": "ASCII_HEAD"},
-        
+
         "PARAMETERS_NAME":
         {"comment": "name of the file containing catalog contents",
          "value": "py-sextractor.param"},
-        
+
         "DETECT_TYPE":
         {"comment": '"CCD" or "PHOTO"',
          "value": "CCD"},
-        
+
         "FLAG_IMAGE":
         {"comment": "filename for an input FLAG-image",
          "value": "flag.fits"},
-        
+
         "DETECT_MINAREA":
         {"comment": "minimum number of pixels above threshold",
          "value": 5},
-        
+
         "DETECT_THRESH":
         {"comment": "<sigmas> or <threshold>,<ZP> in mag.arcsec-2",
          "value": 1.5},
-        
+
         "ANALYSIS_THRESH":
         {"comment": "<sigmas> or <threshold>,<ZP> in mag.arcsec-2",
          "value": 1.5},
-        
+
         "FILTER":
         {"comment": 'apply filter for detection ("Y" or "N")',
          "value": 'Y'},
-        
+
         "FILTER_NAME":
         {"comment": "name of the file containing the filter",
          "value": "py-sextractor.conv"},
-        
+
         "DEBLEND_NTHRESH":
         {"comment": "Number of deblending sub-thresholds",
          "value": 32},
-        
+
         "DEBLEND_MINCONT":
         {"comment": "Minimum contrast parameter for deblending",
          "value": 0.005},
-        
+
         "CLEAN":
         {"comment": "Clean spurious detections (Y or N)",
          "value": 'Y'},
-        
+
         "CLEAN_PARAM":
         {"comment": "Cleaning efficiency",
          "value": 1.0},
-        
+
         "MASK_TYPE":
-        {"comment": 'type of detection MASKing: can be one of "NONE", "BLANK" or "CORRECT"',
+        {"comment": 'type of detection MASKing: can be one of "NONE",'
+                    ' "BLANK" or "CORRECT"',
          "value": "CORRECT"},
-        
+
         "PHOT_APERTURES":
         {"comment": "MAG_APER aperture diameter(s) in pixels",
          "value": 5},
-        
+
         "PHOT_AUTOPARAMS":
         {"comment": 'MAG_AUTO parameters: <Kron_fact>,<min_radius>',
          "value": [2.5, 3.5]},
-        
+
         "SATUR_LEVEL":
         {"comment": "level (in ADUs) at which arises saturation",
          "value": 50000.0},
-        
+
         "MAG_ZEROPOINT":
         {"comment": "magnitude zero-point",
          "value": 0.0},
-        
+
         "MAG_GAMMA":
         {"comment": "gamma of emulsion (for photographic scans)",
          "value": 4.0},
-        
+
         "GAIN":
         {"comment": "detector gain in e-/ADU",
          "value": 0.0},
-        
+
         "PIXEL_SCALE":
         {"comment": "size of pixel in arcsec (0=use FITS WCS info)",
          "value": 1.0},
-        
+
         "SEEING_FWHM":
         {"comment": "stellar FWHM in arcsec",
          "value": 1.2},
-        
+
         "STARNNW_NAME":
         {"comment": "Neural-Network_Weight table filename",
          "value": "py-sextractor.nnw"},
-        
+
         "BACK_SIZE":
         {"comment": "Background mesh: <size> or <width>,<height>",
          "value": 64},
@@ -314,11 +322,11 @@ class SExtractor:
         "BACK_VALUE":
         {"comment": "User-supplied constant value to be subtracted as sky",
          "value": "0.0,0.0"},
-        
+
         "BACK_FILTERSIZE":
         {"comment": "Background filter: <size> or <width>,<height>",
          "value": 3},
-        
+
         "BACKPHOTO_TYPE":
         {"comment": 'can be "GLOBAL" or "LOCAL"',
          "value": "GLOBAL"},
@@ -326,40 +334,43 @@ class SExtractor:
         "BACKPHOTO_THICK":
         {"comment": "Thickness in pixels of the background local annulus",
          "value": 24},
-        
+
         "CHECKIMAGE_TYPE":
-        {"comment": 'can be one of "NONE", "BACKGROUND", "MINIBACKGROUND", "-BACKGROUND", "OBJECTS", "-OBJECTS", "SEGMENTATION", "APERTURES", or "FILTERED"',
+        {"comment": 'can be one of "NONE", "BACKGROUND", "MINIBACKGROUND",'
+                    ' "-BACKGROUND", "OBJECTS", "-OBJECTS", "SEGMENTATION",'
+                    ' "APERTURES", or "FILTERED"',
          "value": "NONE"},
-        
+
         "CHECKIMAGE_NAME":
         {"comment": "Filename for the check-image",
          "value": "check.fits"},
-        
+
         "MEMORY_OBJSTACK":
         {"comment": "number of objects in stack",
          "value": 3000},
-        
+
         "MEMORY_PIXSTACK":
         {"comment": "number of pixels in stack",
          "value": 300000},
-        
+
         "MEMORY_BUFSIZE":
         {"comment": "number of lines in buffer",
          "value": 1024},
-        
+
         "VERBOSE_TYPE":
         {"comment": 'can be "QUIET", "NORMAL" or "FULL"',
          "value": "QUIET"},
-         
+
         "WEIGHT_TYPE":
-        {"comment": 'type of WEIGHTing: NONE, BACKGROUND, MAP_RMS, MAP_VAR or MAP_WEIGHT',
+        {"comment": 'type of WEIGHTing: NONE, BACKGROUND, '
+                    'MAP_RMS, MAP_VAR or MAP_WEIGHT',
          "value": "NONE"},
 
         "WEIGHT_IMAGE":
         {"comment": '# weight-map filename',
          "value": "NONE"},
-                  
-         "WEIGHT_THRESH":
+
+        "WEIGHT_THRESH":
         {"comment": 'weight threshold[s] for bad pixels',
          "value": 0},
 
@@ -367,7 +378,7 @@ class SExtractor:
 
         "PARAMETERS_LIST":
         {"comment": '[Extra key] catalog contents (to put in PARAMETERS_NAME)',
-         "value": ["NUMBER", "FLUX_BEST", "FLUXERR_BEST", 
+         "value": ["NUMBER", "FLUX_BEST", "FLUXERR_BEST",
                    "X_IMAGE", "Y_IMAGE", "FLAGS", "FWHM_IMAGE"]},
 
         "CONFIG_FILE":
@@ -379,27 +390,23 @@ class SExtractor:
          "value": [[1, 2, 1],
                    [2, 4, 2],
                    [1, 2, 1]]}
-        }
+    }
 
-    
     # -- Special config. keys that should not go into the config. file.
 
     _SE_config_special_keys = ["PARAMETERS_LIST", "CONFIG_FILE", "FILTER_MASK"]
 
-
     # -- Dictionary of all possible parameters (from sexcatalog.py module)
 
     _SE_parameters = SExtractorfile._SE_keys
 
-
-
     def __init__(self):
         """
         SExtractor class constructor.
         """
 
         self.config = (
-            dict([(k, copy.deepcopy(SExtractor._SE_config[k]["value"]))\
+            dict([(k, copy.deepcopy(SExtractor._SE_config[k]["value"]))
                   for k in SExtractor._SE_config.keys()]))
 
         # print self.config
@@ -407,7 +414,6 @@ class SExtractor:
         self.program = None
         self.version = None
 
-
     def setup(self, path=None):
         """
         Look for SExtractor program ('sextractor', or 'sex').
@@ -423,47 +429,50 @@ class SExtractor:
 
         if (path):
             candidates = [path]
-        
-        selected=None
+
+        selected = None
         for candidate in candidates:
             try:
                 p = subprocess.Popen(candidate, shell=True,
-                                     stdin=subprocess.PIPE, stdout=subprocess.PIPE,
-                                     stderr=subprocess.STDOUT, close_fds=True)
+                                     stdin=subprocess.PIPE,
+                                     stdout=subprocess.PIPE,
+                                     stderr=subprocess.STDOUT,
+                                     close_fds=True)
                 (_out_err, _in) = (p.stdout, p.stdin)
                 versionline = _out_err.read()
                 if (versionline.find("SExtractor") != -1):
-                    selected=candidate
+                    selected = candidate
                     break
             except IOError:
                 continue
-                
+
         if not(selected):
-            raise SExtractorException, \
-                  """
+            raise SExtractorException(
+                """
                   Cannot find SExtractor program. Check your PATH,
                   or provide the SExtractor program path in the constructor.
                   """
+            )
 
         _program = selected
 
         # print versionline
         _version_match = re.search("[Vv]ersion ([0-9\.])+", versionline)
         if not _version_match:
-            raise SExtractorException, \
-                  "Cannot determine SExtractor version."
+            raise SExtractorException(
+                "Cannot determine SExtractor version."
+            )
 
         _version = _version_match.group()[8:]
         if not _version:
-            raise SExtractorException, \
-                  "Cannot determine SExtractor version."
+            raise SExtractorException(
+                "Cannot determine SExtractor version."
+            )
 
         # print "Use " + self.program + " [" + self.version + "]"
 
         return _program, _version
 
-
-
     def update_config(self):
         """
         Update the configuration files according to the current
@@ -485,7 +494,7 @@ class SExtractor:
         for row in filter:
             filter_f.write(" ".join(map(repr, row)))
             filter_f.write("\n")
-            
+
         filter_f.close()
 
         # -- Write parameter list file
@@ -502,7 +511,6 @@ class SExtractor:
         nnw_f.write(nnw_config)
         nnw_f.close()
 
-
         # -- Write main configuration file
 
         main_f = __builtin__.open(self.config['CONFIG_FILE'], 'w')
@@ -511,18 +519,17 @@ class SExtractor:
             if (key in SExtractor._SE_config_special_keys):
                 continue
 
-            if (key == "PHOT_AUTOPARAMS"): # tuple instead of a single value
+            if (key == "PHOT_AUTOPARAMS"):  # tuple instead of a single value
                 value = " ".join(map(str, self.config[key]))
             else:
                 value = str(self.config[key])
-            
-            
+
             print >>main_f, ("%-16s       %-16s # %s" %
-                             (key, value, SExtractor._SE_config[key]['comment']))
+                             (key, value,
+                              SExtractor._SE_config[key]['comment']))
 
         main_f.close()
 
-
     def run(self, file, updateconfig=True, clean=False, path=None):
         """
         Run SExtractor.
@@ -530,7 +537,7 @@ class SExtractor:
         If updateconfig is True (default), the configuration
         files will be updated before running SExtractor.
 
-        If clean is True (default: False), configuration files 
+        If clean is True (default: False), configuration files
         (if any) will be deleted after SExtractor terminates.
 
         """
@@ -543,20 +550,20 @@ class SExtractor:
 
         self.program, self.version = self.setup(path)
 
-        commandline = (self.program + " -c " + self.config['CONFIG_FILE'] + " " + file)
+        commandline = (
+            self.program + " -c " + self.config['CONFIG_FILE'] + " " + file)
         # print commandline
 
         rcode = os.system(commandline)
 
         if (rcode):
-            raise SExtractorException, \
-                  "SExtractor command [%s] failed." % commandline
-            
+            raise SExtractorException(
+                "SExtractor command [%s] failed." % commandline
+            )
+
         if clean:
             self.clean()
 
-
-
     def catalog(self):
         """
         Read the output catalog produced by the last SExtractor run.
@@ -570,7 +577,6 @@ class SExtractor:
 
         return c
 
-
     def clean(self, config=True, catalog=False, check=False):
         """
         Remove the generated SExtractor files (if any).
@@ -589,10 +595,9 @@ class SExtractor:
                 os.unlink(self.config['CATALOG_NAME'])
             if (check):
                 os.unlink(self.config['CHECKIMAGE_NAME'])
-                
+
         except OSError:
             pass
 
 
-
 # ======================================================================
